﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.IO;
using InvokeSolutions.Docx;
using InvokeSolutions.Docx.Data;
using System.Diagnostics;

namespace SampleComplexObjects
{
    class Program
    {
        class Name
        {
            public string First { get; set; }
            public string Last { get; set; }
        }

        class Item
        {
            public string Name { get; set; }

            public decimal Price { get; set; }
        }

        static void Main(string[] args)
        {
            // create a copy of template file
            File.Copy("template.docx", "report.docx", true);
            File.Copy("template_1.docx", "report_1.docx", true);

            // create datasource
            DocumentDataSource source = new DocumentDataSource();

            source.EmptyValue = "(have no idea)";

            // parsing complex object
            source["USER"] = DataItem.ConvertFrom(new { Name = new Name { First = "Joe", Last = "Bloggs" }, Email = "joe@google.com" });

            // passing array (any IEnumerable is OK) of complex objects as table datasource
            source["ITEMS"] = DataItem.ConvertFrom(new[] { 
                new Item { Name = "Item #1", Price = 3},
                new Item { Name = "Item #2", Price = 2.5m},
                new Item { Name = "Item #3", Price = 1}
            });

            source["DATE"] = DateTime.Today;
            source["ORDERS"] = DataItem.ConvertFrom(
                    new[]{
                        new { ID = Guid.NewGuid().ToString().Substring(0, 8),
                              Account  = new {CompanyName = "Abc Inc."}
                        },
                        new { ID = Guid.NewGuid().ToString().Substring(0, 8),
                              Account  = new {CompanyName = "Klm Inc."}
                        },
                                            new { ID = Guid.NewGuid().ToString().Substring(0, 8),
                              Account  = new {CompanyName = "Xyz Inc."}
                        },
                    }
                );

            // process the document
            DocumentRenderer.ProcessDocument("report.docx", source);
            DocumentRenderer.ProcessDocument("report_1.docx", source);

            Process.Start("report.docx");
            Process.Start("report_1.docx");
        }
    }
}

